@@ -7,5 +7,5 @@ function init(basePath) {
     action.setDefaultCommands(["layerselect", "selectlayer", "y+"]);
     action.setGroupSortOrder(17400);
     action.setSortOrder(100);
-    action.setWidgetNames(["LayerMenu", "LayerToolBar", "LayerToolsPanel"]);
+    action.setWidgetNames(["LayerMenu", "LayerToolBar", "LayerToolsPanel", "LayerMatrixPanel"]);
 }
