@@ -32,28 +32,29 @@ function RCadToolMatrixTreePanel(parent, objectName) {
     layout.setIconSize(new QSize(iconSize, iconSize));
     this.setLayout(layout);
 
-    var pal = new QPalette();
-    var color = pal.color(QPalette.Active, QPalette.Window);
-    var colorName = color.name();
-    var colorLightName = color.lighter(105).name();
+    //var pal = new QPalette();
+    //var color = pal.color(QPalette.Active, QPalette.Window);
+    //var colorName = color.name();
+    //var colorLightName = color.lighter(105).name();
 
     this.styleSheet =
-          "QWidget#" + objectName + " { background: qlineargradient( x1:0 y1:0, x2:1 y2:0, stop:0 " + colorName + ", stop:1 " + colorLightName + "); }"
-        + "QToolButton {"
+          //"QWidget#" + objectName + " { background: qlineargradient( x1:0 y1:0, x2:1 y2:0, stop:0 " + colorName + ", stop:1 " + colorLightName + "); }"
+         "QToolButton {"
         + "  border-style: none;"
         + "}"
         + RCadToolMatrixTreePanel.getCheckedStyle()
         + RCadToolMatrixTreePanel.getPressedStyle();
-
 }
 
 RCadToolMatrixTreePanel.prototype = new QWidget();
 
 RCadToolMatrixTreePanel.getCheckedStyle = function() {
-    return "QToolButton:checked {"
-            + "  border-radius: 4px; "
-            + "  background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #b7b7b7, stop: 0.8 #cfcfcf, stop: 1 #d1d1d1);"
-            + "}";
+    if (!RSettings.hasCustomStyleSheet()) {
+        return "QToolButton:checked {"
+                + "  border-radius: 4px; "
+                + "  background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #b7b7b7, stop: 0.8 #cfcfcf, stop: 1 #d1d1d1);"
+                + "}";
+    }
 };
 
 RCadToolMatrixTreePanel.getPressedStyle = function() {
@@ -120,6 +121,7 @@ function RCadToolMatrixTree(parent) {
     this.indentation = 0;
     this.rootIsDecorated = false;
     this.columnCount = 1;
+    this.setAttribute(Qt.WA_MacShowFocusRect, 0);
     this.selectionMode = QAbstractItemView.NoSelection;
     this.verticalScrollMode = QAbstractItemView.ScrollPerPixel;
     if (RSettings.isQt(5)) {
@@ -191,6 +193,15 @@ RCadToolMatrixTree.prototype.handleItemPress = function(item) {
     if (isNull(item.parent())) {
         item.setExpanded(!item.isExpanded());
     }
+
+    // set focus to mdiChild
+    var appWin = RMainWindowQt.getMainWindow();
+    if (!isNull(appWin)) {
+        var w = appWin.getMdiChild();
+        if (!isNull(w)) {
+            w.setFocus();
+        }
+    }
 };
 
 RCadToolMatrixTree.prototype.mousePressEvent = function(event) {
